<?php

/**
 * Clase ORM para la conexión con la BD
 */

namespace App\ORM;

use App\Entity\GP\TJornada;
use Doctrine\Common\Persistence\ManagerRegistry;
use Symfony\Component\DependencyInjection\ContainerInterface;
use \Doctrine\Common\Persistence\ObjectManager;
use Symfony\Component\Security\Core\Authorization\AuthorizationCheckerInterface;
use \Doctrine\Common\Collections\ArrayCollection;
use Doctrine\ORM\EntityManagerInterface;
use \Exception;
use DateTimeImmutable;
use DateTime;


/**
 * Class Orm
 *
 */
class ORM
{

    private $entityManager;

    public function __construct(EntityManagerInterface $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    /************************************************************
     * LOGIN
     */


    /**
     * comprueba que un usuario exista en la BD
     */
    public function comprobarUsuarioMSLoginBD($mail,  &$sError)
    {
        try {
            $sql = "WITH all_users AS (
                        SELECT 'GA' AS app, ut.email FROM unam_ga.usuarios_t ut
                        UNION
                        SELECT 'GP' AS app, ut2.email FROM unam_gp.usuarios_t ut2
                        UNION
                        SELECT 'SP' AS app, ut3.email FROM unam_tickets.usuarios_t ut3 )
                    SELECT app, email FROM all_users WHERE email ='$mail'";
            $resultado = $this->ejecutarSQLDirecto($sql, $sError);

            return $resultado;
        } catch (Exception $e) {
            $sError .= $e->getMessage();
            throw new Exception(" $sError ");
            return 0;
        }
    }


    /**
     * Eliminar
     */
    public function eliminar($id, $sEntidad, &$sError)
    {

        $oDato = $this->entityManager->getRepository($sEntidad)->find($id);
        try {
            $this->borrarObjetoBD($oDato, $sError);
        } catch (Exception $e) {
            $sError = $e->getMessage();
        }
        return true;
    }

    //obtener datos de una entidad
    public function obtenerEntidad($id = null, $sEntidad = null, $bOrden = false)
    {
        //ORM::depurar(func_get_args());
        if ($id) {
            $oDato = $this->entityManager->getRepository($sEntidad)->find($id);
            return $oDato;
        } elseif ($bOrden) {
            $aDatos = $this->entityManager->getRepository($sEntidad)->findBy([], ['nombre' => 'ASC']);
            return $aDatos;
        } else {
            $aDatos = $this->entityManager->getRepository($sEntidad)->findAll();
            return $aDatos;
        }
    }


    /************************************************************
     * LOG
     */


    //obtiene da la BD los datos de la SQL pasada    
    private function ejecutarSQLDirecto($sql, &$sError)
    {
        try {
            $conn = $this->entityManager->getConnection();
            //ORM::depurar($sql);
            $stmt = $conn->prepare($sql);
            $resultado = $stmt->executeQuery()->fetchAllAssociative();
        } catch (\Exception $e) {
            // Capturar y manejar la excepción
            $sError = "Error al ejecutar la función: $sql " . $e->getMessage();
            $resultado = 0;
        }
        return $resultado;
    }



    /************************************************************
     * AUXILIARES
     */


    /**
     * @param $object
     * @param $sError
     * @return bool
     */
    public function grabarObjetoBD(&$object, &$sError)
    {

        try {

            if (!is_object($object) or ($object == NULL)) {
                throw new \Exception('Imposible grabar, datos vacíos');
            }

            $this->entityManager->persist($object);
            $this->entityManager->flush();

            return TRUE;
        } catch (\Exception $e) {
            throw new \Exception($e);
            //\Doctrine\Common\Util\Debug::dump ( $object );              
            return FALSE;
        }
    }

    /************************************************************/

    /**
     * @param $object
     * @param $sError
     * @return bool
     */
    private function borrarObjetoBD(&$object, &$sError)
    {

        try {

            if (!is_object($object) or ($object == NULL)) {
                throw new \Exception('Imposible eliminar, datos vacíos');
            }

            $this->entityManager->remove($object);
            $this->entityManager->flush();

            return TRUE;
        } catch (\Exception $e) {
            throw new \Exception($e);
            return FALSE;
        }
    }

    /************************************************************/

    /**
     * @param $em
     * @param $sql
     * @return mixed
     */
    private function obtenerSQL($em, $sql)
    {
        $connection = $em->getConnection();
        $results = $connection->executeQuery($sql)->fetchAll();

        return $results;
    }

    /************************************************************/
    /**
     * Muestra por pantalla el valor de la variable
     */
    static function depurar($valor, $doctrine = false, $die = false)
    {
        if ($doctrine) {
            echo "<pre>";
            \Doctrine\Common\Util\Debug::dump($valor);
            echo "</pre>";
        } else {
            echo "<pre>";
            print_r($valor);
            echo "</pre>";
        }

        if ($die) {
            exit();
            die();
        }
    }
} // de la clase